#!/bin/sh
# Sun Jul  1 09:54:11 2001 by AGX

. ansi.inc
TITLE "Preparazione partizioni"
TEMP1="/tmp/temp1"
TEMP2="/tmp/temp2"
rm -f "$TEMP1" "$TEMP2"

# Checking
echoc CYAN "> checking available partitions"
ROOTCOUNT=0
for i in /tmp/parted.*; do
  [ ! -f $i ] && continue
  . $i
  if [ "$DEVMNTP" = "/" ]; then
    if [ $DEVTYPE != "ext2" ]; then
      echoc RED "! the root partition can be only an ext2 filesystem !"
      echoc RED "  Please try again..."
      sleep 2
      exit 2
    fi
    # Save good data
    ROOTCOUNT=$((ROOTCOUNT + 1))
    ROOTDEV=$DEVNAME
    ROOTFILE=$i
    echo $ROOTDEV >/tmp/rootdev
  fi
done
if [ $ROOTCOUNT -eq 0 ]; then
  echoc RED "! no root partition was specified, please try again..."
  sleep 2
  exit 2
fi
if [ $ROOTCOUNT -gt 1 ]; then
  echoc RED "! $ROOTCOUNT root partition was specified, you need only one."
  echoc RED "  Please try again..."
  sleep 2
  exit 2
fi


# Formatting
for i in /tmp/parted.*; do
  [ ! -f $i ] && continue
  . $i
  if [ "$DEVMNTP" != "" ]; then
    if [ "$DEVMKFS" = "yes" ]; then
      if [ "$DEVTYPE" = "ext2" ]; then
        echoc GREEN "> formatting /dev/$DEVNAME"
        mkfs.ext2 -q /dev/$DEVNAME
        R=$?
        if [ $R -gt 1 ]; then
          echoc RED "! format error ($R)"
          sleep 2
	  exit 2
        fi
      else
        echoc YELLOW "! cannot format a $DEVTYPE filesystem"
        echoc YELLOW "  press ENTER to continue or CTRL+C to abort this script"
        read x
      fi
    fi
  fi
done


# Checking
echoc GREEN "> checking selected filesystems"
for i in /tmp/parted.*; do
  [ ! -f $i ] && continue
  . $i
  if [ "$DEVMNTP" != "" ]; then
    fsck -f -C -T -p /dev/$DEVNAME
    R=$?
    if [ $R -gt 1 ]; then
      echoc YELLOW "! filesystem checking has failed for $DEVNAME"
      sleep 1
    fi
  fi
done

# Sort mount point
>$TEMP1
for i in /tmp/parted.*; do
  [ ! -f $i ] && continue
  . $i
  if [ "$DEVMNTP" != "" ]; then
    echo "$DEVNAME|$DEVTYPE|$DEVMNTP" >>$TEMP1
  fi
done
sort -t '|' -k 3 -o $TEMP2  $TEMP1

# Mount Root First
for i in `cat $TEMP2` ; do
  TEMPFILE="/tmp/parted.`echo $i | cut -d'|' -f1`"
  [ ! -f $TEMPFILE ] && continue
  . $TEMPFILE
  echoc GREEN "> mounting $DEVNAME ($DEVTYPE) under $DEVMNTP"
  mkdir -p /mnt/target${DEVMNTP}
  mount /dev/$DEVNAME /mnt/target/ -t $DEVTYPE -o rw
  R=$?
  if [ $R -ne 0 ]; then
    echoc RED "! unable to mount $DEVNAME ($DEVTYPE) under $DEVMNTP"
    sleep 2
    exit 2
  fi
done

echoc GREEN "- tutte le partizioni sono state montate con successo"
sleep 1

echoc CYAN "> configuro il filesystem target"
mkdir -p /mnt/target/dev/pts
mkdir -p /mnt/target/etc
mkdir -p /mnt/target/var/log
mkdir -p /mnt/target/var/run
mkdir -p /mnt/target/var/spool/badpenguin
mkdir -p /mnt/target/tmp
mkdir -p /mnt/target/var
( cd /mnt/target/var ; ln -sf ../tmp tmp )

echoc GREEN "> creo /etc/fstab sul dispositivo target"
touch /mnt/target/etc/fstab
grep swap /mnt/target/etc/fstab > /mnt/target/etc/fstab.new
echo "
none	/proc	proc	 defaults	1	1
/dev/fd0	/floppy	auto	noauto	1	1
/dev/cdrom	/cdrom	iso9660	noauto,check=relaxed,ro,user	0	0
none		/dev/pts	devpts  gid=5,mode=620			0	0
" >> /mnt/target/etc/fstab.new
mv -vf /mnt/target/etc/fstab.new /mnt/target/etc/fstab
>/mnt/target/etc/mtab

# Mount Root First
for i in `cat $TEMP2` ; do
  TEMPFILE="/tmp/parted.`echo $i | cut -d'|' -f1`"
  [ ! -f $TEMPFILE ] && continue
  . $TEMPFILE
  echo "/dev/$DEVNAME	$DEVMNTP	$DEVTYPE	defaults	1	1"  >>/mnt/target/etc/fstab
done

# Making root dirs
echoc GREEN "> creo directory da /etc/fstab"
cat /mnt/target/etc/fstab | cut -f 2 | grep "^/" | while read DIR
do
  mkdir -p "/mnt/target$DIR"
done

echoc PURPLE "- ready to install..."
sleep 2


# DONE!
echo "- launching install.sh"
echo "./install.sh"  >/tmp/ACTION
exit 0
